function [F, V] = polyQuadBelg(rad, pStart, pEnd, noZlevels, noDiskRings, noSec)
    % Quad poly, med lokk
    % rad - er radius
    % pStart, pEnd -er senterpunkt xyz for start og slutt på rør
    % noSec - er antall polygonsider, mange sider gir treg beregning
    % noDiskRings - antall ringer i lokkene

%     noZlevels = 10;
%     noDiskRings = 8;
%     noSec = 64;
    
    h = norm(pEnd - pStart);

    Vsum = [];
    Fsum = [];

    % vegger
    for sec = 0 : noZlevels - 1
        if mod(sec,2) == 1
            upDir = 0;
        else
            upDir = 1;
        end
        [F, V] = polyQuadOpenC(rad, noSec, [0 0 sec/noZlevels], [0 0 (sec + 1)/noZlevels], upDir);
        [Fsum, Vsum] = addPoly(Fsum, Vsum, F, V);
    end

    % tak
    [F, V] = polyQuadDiskSemiClosed(rad, noSec, noDiskRings);
    V = V + [0 0 1];
    [Fsum, Vsum] = addPoly(Fsum, Vsum, F, V);

    % bunn
    [F, V] = polyQuadDiskSemiClosed(rad, noSec, noDiskRings);
    F = flip(F, 2); 
    [Fsum, Vsum] = addPoly(Fsum, Vsum, F, V);

    Vtot = round(Vsum*100000)./100000;
    [V,~, ic] = unique(Vtot(:, 1:3), 'rows');
    F =  ic(Fsum);

    % skalerer

    V = V.*[1 1 h];

end

function [F, V] = polyQuadOpenC(rad, noSec, poiStart, poiEnd, upDir)

    V = zeros(noSec*2, 3);
    F = zeros(noSec, 4); 

    if upDir == 0
        rad2 = rad*0.8;
    else
        rad2 = rad;
    end
    vi = 1;
    for v = 0 : 2*pi/noSec : 2*pi - 2*pi/noSec
        V(vi, 1) = rad2 * cos(v);
        V(vi, 2) = rad2 * sin(v);
        V(vi, 3) = 0;
    
        vi = vi + 1;
    end

    if upDir == 1
        rad2 = rad*0.8;
    else
        rad2 = rad;
    end
    for v = 0 : 2*pi/noSec : 2*pi - 2*pi/noSec
        V(vi, 1) = rad2 * cos(v);
        V(vi, 2) = rad2 * sin(v);
        V(vi, 3) = 1;
    
        vi = vi + 1;
    end

    % Faces

    f = 1;
    for vi = 1 : noSec
        F(f, 1) = vi;
        F(f, 2) = mod(vi,noSec) + 1;
        F(f, 3) = mod(vi,noSec) + 1 + noSec;
        F(f, 4) = vi + noSec;
    
        f = f + 1;
    end

    % skalerer

    h = norm(poiEnd - poiStart);
    V = V.*[1 1 h];

    V = V + poiStart;

end